@@ -5,7 +5,7 @@ use 5.010;
 
 # PODNAME: pwgen-xkcd.pl
 # ABSTRACT: Generate a xkcd-style password
-our $VERSION = '1.010'; # VERSION
+our $VERSION = '1.011'; # VERSION
 
 use CtrlO::Crypt::XkcdPassword;
 use Getopt::Long;
@@ -16,16 +16,18 @@ binmode STDOUT, ":utf8";
 my $words    = 4;
 my $digits   = 0;
 my $language = 'en-GB';
+my $wordlist = '';
 my $help     = 0;
 
 GetOptions(
     "words=i"    => \$words,
     "digits=i"   => \$digits,
     "language=s" => \$language,
+    "wordlist=s" => \$wordlist,
     "help|?"     => \$help
 );
 pod2usage(1) if ($help);
-say CtrlO::Crypt::XkcdPassword->new( language => $language )
+say CtrlO::Crypt::XkcdPassword->new( language => $language, wordlist => $wordlist )
     ->xkcd( words => $words, digits => $digits );
 
 __END__
@@ -40,7 +42,7 @@ pwgen-xkcd.pl - Generate a xkcd-style password
 
 =head1 VERSION
 
-version 1.010
+version 1.011
 
 =head1 USAGE
 
@@ -50,6 +52,8 @@ version 1.010
     --words      Number of words to generate, default 4
     --digits     Add some digits, default 0
     --language   Language of word list, default en-GB
+    --wordlist   file containing one word per line
+                   or Perl module implementing a wordlist
 
 =head1 SEE ALSO
 
